@@ -148,12 +148,15 @@ GstDialogSignal signals[] = {
 };
 
 GstDialogSignal signals_after[] = {
+	{ "network_connection_page1", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page2", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
 	{ "network_connection_wireless_page", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_other_page1",  "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_plip_page1",  "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page1",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page2",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_name",    "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_other_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_plip_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page2", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_name", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_finish", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
 	{ NULL }
 };
 
@@ -251,12 +254,12 @@ main (int argc, char *argv[])
 	
 	struct poptOption options[] =
 	{
-		{ "new-connection", '\0', 0, &connection, 0, _("Run the connection druid."), NULL },
-		{ "ppp-connection", '\0', 0, &ppp_connection, 0, _("Run the PPP connection druid."), NULL },
-		{ "eth-connection", '\0', 0, &eth_connection, 0, _("Run the ethernet connection druid."), NULL },
-		{ "wlan-connection", '\0', 0, &wlan_connection, 0, _("Run the wlan connection druid."), NULL },
-		{ "plip-connection", '\0', 0, &plip_connection, 0, _("Run the parallel port connection druid."), NULL },
-		{ "irlan-connection", '\0', 0, &irlan_connection, 0, _("Run the irlan connection druid."), NULL },
+		{ "new-connection", '\0', 0, &connection, 0, _("Run the connection assistant."), NULL },
+		{ "ppp-connection", '\0', 0, &ppp_connection, 0, _("Run the PPP connection assistant."), NULL },
+		{ "eth-connection", '\0', 0, &eth_connection, 0, _("Run the ethernet connection assistant."), NULL },
+		{ "wlan-connection", '\0', 0, &wlan_connection, 0, _("Run the wlan connection assistant."), NULL },
+		{ "plip-connection", '\0', 0, &plip_connection, 0, _("Run the parallel port connection assistant."), NULL },
+		{ "irlan-connection", '\0', 0, &irlan_connection, 0, _("Run the irlan connection assistant."), NULL },
 		{ "configure", '\0', POPT_ARG_STRING, &interface, 0, _("Configure a network interface"), _("interface") },
 		
 		{NULL, '\0', 0, NULL, 0}
@@ -289,7 +292,7 @@ main (int argc, char *argv[])
 
 		connect_signals (tool->main_dialog, signals, signals_after);
 		init_editable_filters (tool->main_dialog);
-		network_druid_new (druid, tool, type);
+		network_druid_new (druid, druid_window, tool, type);
 		gtk_widget_show_all (druid_window);
 
 		gst_tool_main_with_hidden_dialog (tool, FALSE);
