@@ -29,15 +29,41 @@
 #include "callbacks.h"
 #include "connection.h"
 
+static void
+network_druid_fill_wireless_devices_list (GstTool *tool)
+{
+	GtkWidget *combo = gst_dialog_get_widget (tool->main_dialog,
+						  "network_connection_wireless_device");
+	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
+	xmlNodePtr node;
+	GList *devices = NULL;
+	
+	for (node = gst_xml_element_find_first (root, "wireless_device");
+	     node != NULL;
+	     node = gst_xml_element_find_next (node, "wireless_device"))
+	{
+		devices = g_list_append (devices, gst_xml_element_get_content (node));
+	}
+
+	if (devices)
+		gtk_combo_set_popdown_strings (GTK_COMBO (combo), devices);
+}
+
 void
-network_druid_new (GnomeDruid *druid, GstTool *tool, GstConnectionType type)
+network_druid_new (GnomeDruid *druid, GtkWidget *window, GstTool *tool, GstConnectionType type)
 {
 	NetworkDruidData *druid_data = g_new0 (NetworkDruidData, 1);
 
+	druid_data->window = window;
 	druid_data->tool = tool;
 	druid_data->current_page = NETWORK_DRUID_START;
 	druid_data->cxn = connection_new_from_type (type, gst_xml_doc_get_root (tool->config));
 
+	/* set window titles */
+	druid_data->first_page_title = N_("Creating a new network connection");
+	druid_data->title = N_("Creating a new network connection (%d of %d)");
+	druid_data->finish_title = N_("Finished creating a new network connection");
+
 	if (type == GST_CONNECTION_UNKNOWN)
 		druid_data->fixed_type = FALSE;
 	else
@@ -53,6 +79,8 @@ network_druid_clear (GnomeDruid *druid, gboolean destroy_data)
 	GstTool *tool = druid_data->tool;
 	GtkWidget *widget;
 	gchar *entries [] = {
+		"network_connection_wireless_device_entry",
+		"network_connection_essid",
 		"network_connection_other_ip_address",
 		"network_connection_other_ip_mask",
 		"network_connection_other_gateway",
@@ -98,6 +126,7 @@ network_druid_get_connection_data (GnomeDruid *druid)
 
 	if (cxn->type == GST_CONNECTION_PPP) {
 		GtkWidget *phone = gst_dialog_get_widget (tool->main_dialog, "network_connection_ppp_phone");
+		GtkWidget *external_line = gst_dialog_get_widget (tool->main_dialog, "network_connection_external_line");
 		GtkWidget *login = gst_dialog_get_widget (tool->main_dialog, "network_connection_ppp_login");
 		GtkWidget *passwd = gst_dialog_get_widget (tool->main_dialog, "network_connection_ppp_passwd1");
 		GtkWidget *name = gst_dialog_get_widget (tool->main_dialog, "network_connection_name");
@@ -108,6 +137,7 @@ network_druid_get_connection_data (GnomeDruid *druid)
 
 		cxn->serial_port = modem;
 		cxn->phone_number = g_strdup (gtk_entry_get_text (GTK_ENTRY (phone)));
+		cxn->external_line = g_strdup (gtk_entry_get_text (GTK_ENTRY (external_line)));
 		cxn->login = g_strdup (gtk_entry_get_text (GTK_ENTRY (login)));
 		cxn->password = g_strdup (gtk_entry_get_text (GTK_ENTRY (passwd)));
 		cxn->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (name)));
@@ -154,12 +184,22 @@ network_druid_get_connection_data (GnomeDruid *druid)
 		GtkWidget *name = gst_dialog_get_widget (tool->main_dialog,
 							 "network_connection_name");
 
+		if (cxn->type == GST_CONNECTION_WLAN) {
+			GtkWidget *device = gst_dialog_get_widget (tool->main_dialog,
+								   "network_connection_wireless_device_entry");
+			GtkWidget *essid = gst_dialog_get_widget (tool->main_dialog,
+								  "network_connection_essid");
+			cxn->dev = g_strdup (gtk_entry_get_text (GTK_ENTRY (device)));
+			cxn->essid = g_strdup (gtk_entry_get_text (GTK_ENTRY (essid)));
+		} else {
+			cxn->dev = connection_find_new_device (root, cxn->type);
+		}
+			
 		cxn->ip_config = gtk_option_menu_get_history (GTK_OPTION_MENU (type));
 		cxn->address = g_strdup (gtk_entry_get_text (GTK_ENTRY (ip_address)));
 		cxn->netmask = g_strdup (gtk_entry_get_text (GTK_ENTRY (ip_mask)));
 		cxn->gateway = g_strdup (gtk_entry_get_text (GTK_ENTRY (gateway)));
 		cxn->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (name)));
-		cxn->dev = connection_find_new_device (root, cxn->type);
 		connection_set_bcast_and_network (cxn);
 
 		cxn->user = TRUE;
@@ -231,18 +271,15 @@ network_druid_check_login_password (GnomeDruid *druid)
 }
 
 static gboolean
-network_druid_check_account_name (GnomeDruid *druid)
+network_druid_check_entry (GnomeDruid *druid, gchar *widget_name)
 {
 	NetworkDruidData *druid_data = g_object_get_data (G_OBJECT (druid), "data");
 
 	GtkWidget *account = gst_dialog_get_widget (druid_data->tool->main_dialog,
-						    "network_connection_name");
+						    widget_name);
 	gchar *text = (gchar*) gtk_entry_get_text (GTK_ENTRY (account));
 
-	if (strcmp (text, "") != 0)
-		return TRUE;
-	else
-		return FALSE;
+	return (strcmp (text, "") != 0);
 }
 
 static gboolean
@@ -289,6 +326,10 @@ network_druid_check_page (GnomeDruid *druid, NetworkDruidPages page_number)
 	gboolean cont;
 
 	switch (page_number) {
+	case NETWORK_DRUID_WIRELESS:
+		cont = network_druid_check_entry (druid, "network_connection_wireless_device_entry") &&
+			network_druid_check_entry (druid, "network_connection_essid");
+		break;
 	case NETWORK_DRUID_OTHER_1:
 		cont = network_druid_check_ip (druid);
 		break;
@@ -302,7 +343,7 @@ network_druid_check_page (GnomeDruid *druid, NetworkDruidPages page_number)
 		cont = network_druid_check_login_password (druid);
 		break;
 	case NETWORK_DRUID_NAME:
-		cont = network_druid_check_account_name (druid);
+		cont = network_druid_check_entry (druid, "network_connection_name");
 		break;
 	}
 
@@ -343,55 +384,72 @@ network_druid_set_page_next (GnomeDruid *druid)
 										     "network_connection_plip_page1"));
 				gnome_druid_set_page (druid, next_page);
 			
+				return TRUE;
+			} else if (druid_data->cxn->type == GST_CONNECTION_WLAN) {
+				network_druid_fill_wireless_devices_list (druid_data->tool);
+				
+				druid_data->current_page = NETWORK_DRUID_WIRELESS;
+
+				next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
+										     "network_connection_wireless_page"));
+				gnome_druid_set_page (druid, next_page);
+
 				return TRUE;
 			} else {
+				druid_data->current_page = NETWORK_DRUID_OTHER_1;
+				next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
+										     "network_connection_other_page1"));
+				
 				switch (druid_data->cxn->type) {
 				case GST_CONNECTION_ETH:
 					image_path = g_strdup_printf (PIXMAPS_DIR "/connection-ethernet.png");
 					break;
-				case GST_CONNECTION_WLAN:
-					image_path = g_strdup_printf (PIXMAPS_DIR "/wavelan-48.png");
-					break;
 				case GST_CONNECTION_IRLAN:
 					image_path = g_strdup_printf (PIXMAPS_DIR "/irda-48.png");
 					break;
 				}
 
 				image = gdk_pixbuf_new_from_file (image_path, NULL);
-				gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD (gst_dialog_get_widget (tool->main_dialog, "network_connection_other_page1")), image);
-				
+				gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD (next_page), image);
 				g_free (image_path);
 				gdk_pixbuf_unref (image);
 
-				druid_data->current_page = NETWORK_DRUID_OTHER_1;
-				next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
-										     "network_connection_other_page1"));
 				gnome_druid_set_page (druid, next_page);
 			
 				return TRUE;
 			}
 		}
 
+		break;
+	case NETWORK_DRUID_WIRELESS:
+		druid_data->current_page = NETWORK_DRUID_OTHER_1;
+		next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
+								     "network_connection_other_page1"));
+
+		/* set the wireless image to the druid */
+		image_path = g_strdup_printf (PIXMAPS_DIR "/wavelan-48.png");
+		image = gdk_pixbuf_new_from_file (image_path, NULL);
+		gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD (next_page), image);
+				
+		g_free (image_path);
+		gdk_pixbuf_unref (image);
+
+		gnome_druid_set_page (druid, next_page);
+
+		return TRUE;
 		break;
 	case NETWORK_DRUID_OTHER_1:
 	case NETWORK_DRUID_PLIP_1:
 		druid_data->current_page = NETWORK_DRUID_NAME;
 		next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
 								     "network_connection_page_name"));
-		gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD (next_page),
-						     _("Connection name (Step 2 of 2)"));
-		
 		gnome_druid_set_page (druid, next_page);
-		
 		return TRUE;
 		break;
 	case NETWORK_DRUID_PPP_2:
 		druid_data->current_page = NETWORK_DRUID_NAME;
 		next_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
 								     "network_connection_page_name"));
-		gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD (next_page),
-						     _("Connection name (Step 3 of 3)"));
-
 		return FALSE;
 		break;
 	}
@@ -409,9 +467,19 @@ network_druid_set_page_back (GnomeDruid *druid)
 
 	g_return_val_if_fail (druid_data != NULL, FALSE);
 
-	if ((druid_data->current_page == NETWORK_DRUID_PPP_1) ||
-	    (druid_data->current_page == NETWORK_DRUID_PLIP_1) ||
-	    (druid_data->current_page == NETWORK_DRUID_OTHER_1)) {
+	if ((druid_data->current_page == NETWORK_DRUID_OTHER_1) &&
+	    (druid_data->cxn->type == GST_CONNECTION_WLAN)) {
+		druid_data->current_page = NETWORK_DRUID_WIRELESS;
+		back_page = GNOME_DRUID_PAGE (gst_dialog_get_widget (druid_data->tool->main_dialog,
+								     "network_connection_wireless_page"));
+		gnome_druid_set_page (druid, back_page);
+		
+		return TRUE;
+	} else if ((druid_data->current_page == NETWORK_DRUID_PPP_1) ||
+		   (druid_data->current_page == NETWORK_DRUID_PLIP_1) ||
+		   (druid_data->current_page == NETWORK_DRUID_WIRELESS) ||
+		   ((druid_data->current_page == NETWORK_DRUID_OTHER_1) &&
+		    (druid_data->cxn->type != GST_CONNECTION_WLAN))) {
 		if (druid_data->fixed_type) {
 			druid_data->current_page = NETWORK_DRUID_START;
 		
@@ -450,3 +518,83 @@ network_druid_set_page_back (GnomeDruid *druid)
 
 	return FALSE;
 }
+
+void
+network_druid_set_window_title (GnomeDruid *druid)
+{
+	NetworkDruidData *druid_data = g_object_get_data (G_OBJECT (druid), "data");
+	gint total_pages;
+	gint current_page;
+	NetworkDruidPageType page_type;
+	gchar *title;
+
+	/* let's guess the total number of pages that the assistant will have */
+	switch (druid_data->cxn->type) {
+	case GST_CONNECTION_PPP:
+	case GST_CONNECTION_WLAN:
+		total_pages = 3;
+		break;
+	case GST_CONNECTION_ETH:
+	case GST_CONNECTION_PLIP:
+	case GST_CONNECTION_IRLAN:
+	default:
+		total_pages = 2;
+		break;
+	}
+
+	/* ok, now let's go for the current page */
+	switch (druid_data->current_page) {
+	case NETWORK_DRUID_START:
+	case NETWORK_DRUID_CONNECTION_TYPE:
+		page_type = DRUID_START_PAGE;
+		break;
+	case NETWORK_DRUID_WIRELESS:
+		page_type = DRUID_NORMAL_PAGE;
+		current_page = 1;
+		break;
+	case NETWORK_DRUID_OTHER_1:
+		page_type = DRUID_NORMAL_PAGE;
+
+		if (druid_data->cxn->type == GST_CONNECTION_WLAN)
+			current_page = 2;
+		else
+			current_page = 1;
+		break;
+	case NETWORK_DRUID_PLIP_1:
+		page_type = DRUID_NORMAL_PAGE;
+		current_page = 1;
+		break;
+	case NETWORK_DRUID_PPP_1:
+		page_type = DRUID_NORMAL_PAGE;
+		current_page = 1;
+		break;
+	case NETWORK_DRUID_PPP_2:
+		page_type = DRUID_NORMAL_PAGE;
+		current_page = 2;
+		break;
+	case NETWORK_DRUID_NAME:
+		page_type = DRUID_NORMAL_PAGE;
+
+		if ((druid_data->cxn->type == GST_CONNECTION_WLAN) ||
+		    (druid_data->cxn->type == GST_CONNECTION_PPP))
+			current_page = 3;
+		else
+			current_page = 2;
+		break;
+	case NETWORK_DRUID_FINISH:
+		page_type = DRUID_FINISH_PAGE;
+		break;
+	}
+
+	if (page_type == DRUID_START_PAGE)
+	gtk_window_set_title (GTK_WINDOW (druid_data->window),
+				      druid_data->first_page_title);
+	else if (page_type == DRUID_FINISH_PAGE)
+		gtk_window_set_title (GTK_WINDOW (druid_data->window),
+				      druid_data->finish_title);
+	else {
+		title = g_strdup_printf (druid_data->title, current_page, total_pages);
+		gtk_window_set_title (GTK_WINDOW (druid_data->window), title);
+		g_free (title);
+	}
+}
