@@ -24,7 +24,7 @@
  *          Chema Celorio <chema@ximian.com>
  *          Carlos Garnacho Parro <garparr@teleline.es>
  */
-
+ 
 #include <config.h>
 
 #include <stdio.h>
@@ -126,13 +126,6 @@ static GstDialogSignal signals[] = {
 	{ "ntp_use",           "toggled",            G_CALLBACK (ntp_use_toggled) },
 	{ "timeserver_button", "clicked",            G_CALLBACK (server_button_clicked) },
 	{ "location_combo",    "set_focus_child",    G_CALLBACK (gst_dialog_modify_cb) },
-#warning FIXME
-#if 0
-	{ "tz_combo_entry",    "changed",            G_CALLBACK (update_tz) },
-#endif
-        /* Changed the Signal for the GtkTreeView --AleX
-	   { "ntp_list",          "selection_changed",  gst_dialog_modify_cb },
-	   { "ntp_list2",         "cursor_changed",     G_CALLBACK (gst_dialog_modify_cb) },*/
 	{ "ntp_add_server",    "clicked",            G_CALLBACK (on_ntp_addserver) },
 	{ "ntp_add_server",    "clicked",            G_CALLBACK (gst_dialog_modify_cb) },
 	{ NULL }
@@ -265,14 +258,24 @@ gst_time_update_date (GstTimeTool *tool, gint add)
 void
 gst_time_update (GstTimeTool *tool)
 {
+	gchar *s, *m, *h;
+	
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->seconds), (gfloat) tool->sec);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->minutes), (gfloat) tool->min);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->hours), (gfloat) tool->hrs);
 	
 	/* we add the 0 if the number is <= 9, it's more pretty */
-	gtk_entry_set_text (GTK_ENTRY (tool->seconds), g_strdup_printf ("%02d", tool->sec));
-	gtk_entry_set_text (GTK_ENTRY (tool->minutes), g_strdup_printf ("%02d", tool->min));
-	gtk_entry_set_text (GTK_ENTRY (tool->hours), g_strdup_printf ("%02d", tool->hrs));
+	s = g_strdup_printf ("%02d", tool->sec);
+	m = g_strdup_printf ("%02d", tool->min);
+	h = g_strdup_printf ("%02d", tool->hrs);
+	
+	gtk_entry_set_text (GTK_ENTRY (tool->seconds), s);
+	gtk_entry_set_text (GTK_ENTRY (tool->minutes), m);
+	gtk_entry_set_text (GTK_ENTRY (tool->hours), h);
+
+	g_free (s);
+	g_free (m);
+	g_free (h);
 }
 
 static gboolean
@@ -307,12 +310,10 @@ timezone_construct_dialog (GstDialog *dialog)
 	g_return_if_fail (dialog!=NULL);
 	g_return_if_fail (GST_IS_DIALOG(dialog));
 	
-	d = gtk_dialog_new_with_buttons (_("Time Zone - GNOME System Tools"),
+	d = gtk_dialog_new_with_buttons (_("Time Zone"),
 					      NULL,
 					      GTK_DIALOG_MODAL |
 					      GTK_DIALOG_NO_SEPARATOR,
-					      GTK_STOCK_APPLY,
-					      GTK_RESPONSE_APPLY,
 					      GTK_STOCK_CLOSE,
 					      GTK_RESPONSE_CLOSE, NULL);
 
@@ -381,29 +382,28 @@ timezone_button_clicked (GtkWidget *w, gpointer data)
 	GstDialog *dialog;
 	GstTimeTool *time_tool;
 	gint result;
+	gchar *tz_name = NULL;
+	gchar *old_tz_name = NULL;
+	TzLocation *tz_location;
+	gint correction;
 
 	dialog = GST_DIALOG (data);
 	time_tool = GST_TIME_TOOL (gst_dialog_get_tool (dialog));
 
-	if (!d) {
+	if (!d)
 		d = timezone_construct_dialog (dialog);
-	}
 
-	if (time_tool->time_zone_name) {
+	if (time_tool->time_zone_name)
 		e_tz_map_set_tz_from_name (tzmap, time_tool->time_zone_name);
-	}
-
-	gtk_widget_show (d);
 
 	result = gtk_dialog_run (GTK_DIALOG (d));
-	if (result == GTK_RESPONSE_APPLY) {
-		gchar *tz_name;
-		TzLocation *tz_location;
-		gint correction;
 
-		tz_name     = e_tz_map_get_selected_tz_name (tzmap);
-		tz_location = e_tz_map_get_location_by_name (tzmap, tz_name);
+	tz_name     = e_tz_map_get_selected_tz_name (tzmap);
+	tz_location = e_tz_map_get_location_by_name (tzmap, tz_name);
 
+	old_tz_name = gst_time_tool_get_time_zone_name (time_tool);
+
+	if ((!old_tz_name) || ((old_tz_name) && (strcmp (tz_name, old_tz_name) != 0))) {
 		correction = tz_location_set_locally (tz_location);
 		gst_time_tool_set_time_zone_name (time_tool, tz_name);
 		gst_time_set_from_localtime (time_tool, correction);
@@ -425,7 +425,7 @@ server_construct_dialog (GstDialog *dialog)
 	g_return_if_fail (dialog!=NULL);
 	g_return_if_fail (GST_IS_DIALOG(dialog));
 
-	d = gtk_dialog_new_with_buttons (_("Time Servers - GNOME System Tools"),
+	d = gtk_dialog_new_with_buttons (_("Time Servers"),
 					      NULL,
 					      GTK_DIALOG_MODAL |
 					      GTK_DIALOG_NO_SEPARATOR,
@@ -484,6 +484,12 @@ gst_time_tool_set_time_zone_name (GstTimeTool *time_tool, gchar *name)
 	update_tz (time_tool);
 }
 
+gchar*
+gst_time_tool_get_time_zone_name (GstTimeTool *time_tool)
+{
+	return time_tool->time_zone_name;
+}
+
 static void
 ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 {
@@ -497,7 +503,7 @@ ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 		GtkWidget *dialog;
 		
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("You don't have NTP support running. Please run NTP support\nin the system to enable server synchronization."));
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("You don't have NTP support running. Please run NTP support in the system to enable server synchronization."));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		return;
@@ -561,7 +567,7 @@ gst_time_filter (GtkEntry *entry, const gchar *new_text,
 	gchar new_val_string [4];
 	gint new_val;
 	gint max = (widget == tool->hours) ? 24 : 60;
-	
+
 	if (tool->ticking)
 		return;
 	if (length > 1)
@@ -569,7 +575,7 @@ gst_time_filter (GtkEntry *entry, const gchar *new_text,
 	
 	gst_time_clock_stop (tool);
 	text = gtk_entry_get_text (entry);
-	
+
 	/*
 	 * Get the resulting string after this insert text event
 	 * and its numberical value
@@ -600,12 +606,17 @@ gst_time_filter (GtkEntry *entry, const gchar *new_text,
 	gst_dialog_modify (GST_TOOL (tool)->main_dialog);
 }
 
+static void
+gst_time_focus_in (GtkWidget *widget, GdkEventFocus *event, GstTimeTool *tool)
+{
+	gst_time_clock_stop (tool);
+}
+
 static void
 gst_time_focus_out (GtkWidget *widget, GdkEventFocus *event, GstTimeTool *tool)
 {
 	gint num = atoi (gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1));
-
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (widget), "focus_out_event");
+	gchar *value;
 
 	if (widget == tool->seconds) {
 		tool->sec = num;
@@ -616,7 +627,10 @@ gst_time_focus_out (GtkWidget *widget, GdkEventFocus *event, GstTimeTool *tool)
 	}
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), (gfloat) num);
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (widget), "focus_out_event");
+
+	value = g_strdup_printf ("%02d", num);
+	gtk_entry_set_text (GTK_ENTRY (widget), value);
+	g_free (value);
 }
 
 static void
@@ -624,6 +638,7 @@ gst_time_change (GtkSpinButton *widget, gpointer data)
 {
 	GstTimeTool *tool = data;
 	gint value = gtk_spin_button_get_value (widget);
+	gchar *val;
 
 	g_return_if_fail (GTK_IS_SPIN_BUTTON (widget));
 	g_return_if_fail (GST_IS_TIME_TOOL (tool));
@@ -632,17 +647,21 @@ gst_time_change (GtkSpinButton *widget, gpointer data)
 		if (value > 59) {
 			gtk_spin_button_set_value (widget, value - 60);
 			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->minutes), GTK_SPIN_STEP_FORWARD, 1);
+			tool->min++;
 		} else if (value < 0) {
 			gtk_spin_button_set_value (widget, value + 60);
 			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->minutes), GTK_SPIN_STEP_BACKWARD, 1);
+			tool->min--;
 		}
 	} else if (widget == GTK_SPIN_BUTTON (tool->minutes)) {
 		if (value > 59) {
 			gtk_spin_button_set_value (widget, value - 60);
 			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->hours), GTK_SPIN_STEP_FORWARD, 1);
+			tool->hrs++;
 		} else if (value < 0) {
 			gtk_spin_button_set_value (widget, value + 60);
 			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->hours), GTK_SPIN_STEP_BACKWARD, 1);
+			tool->hrs--;
 		}
 	} else if (widget == GTK_SPIN_BUTTON (tool->hours)) {
 		if (value > 23) {
@@ -658,7 +677,9 @@ gst_time_change (GtkSpinButton *widget, gpointer data)
 	gst_time_clock_stop (tool);
 	
 	/* We have to set it to 01 instead of 1, it's more pretty */
-	gtk_entry_set_text (GTK_ENTRY (widget), g_strdup_printf ("%02d", value));
+	val = g_strdup_printf ("%02d", value);
+	gtk_entry_set_text (GTK_ENTRY (widget), val);
+	g_free (val);
 }
 
 static GtkWidget *
@@ -670,9 +691,12 @@ gst_time_spin_button_create (GstTimeTool *tool, gchar *label)
 	g_signal_connect (G_OBJECT (spin), "insert_text",
 			  G_CALLBACK (gst_time_filter),
 			  tool);
-	g_signal_connect (G_OBJECT (spin), "key_press_event",
+	/* g_signal_connect (G_OBJECT (spin), "key_press_event",
 			  G_CALLBACK (gst_time_key_press_event_cb),
-			  tool);
+			  tool);*/
+	g_signal_connect_after (G_OBJECT (spin), "focus_in_event",
+			        G_CALLBACK (gst_time_focus_in),
+			        tool);
 	g_signal_connect_after (G_OBJECT (spin), "focus_out_event",
 			        G_CALLBACK (gst_time_focus_out),
 			        tool);
